try:
    from . import fastgl_wrap
except ModuleNotFoundError:
    print('fastgl not found')
    fastgl_wrap = None

leggauss = getattr(fastgl_wrap, 'leggauss', None)
getGLPair = getattr(fastgl_wrap, 'getGLPair', None)


# cython: language_level = 3str

cdef extern from "fastgl.cpp":
    pass

cdef extern from "fastgl.h" namespace "fastgl":

    ctypedef struct QuadPair:
        double theta
        double weight
        double x()

    cdef QuadPair GLPair(int, int)



cdef int get_number_of_blocks(int level, long* D, int N)
cdef int get_h(int level, long* D, int N)
cdef int get_number_of_submatrices(long* D, int L)
cdef void get_ij(int* ij, int level, int block, int diags, int h, int s, long* D, int L)
